self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "55c3ac3cb4a9bac61e9a542dc4cafc7c",
    "url": "./index.html"
  },
  {
    "revision": "5921b2f278273442bb61",
    "url": "./static/js/2.6665ad20.chunk.js"
  },
  {
    "revision": "22d1553f76a9ff7922f2f7b126ef7063",
    "url": "./static/js/2.6665ad20.chunk.js.LICENSE.txt"
  },
  {
    "revision": "3a535c0f007a82b16d1c",
    "url": "./static/js/main.6aa5e729.chunk.js"
  },
  {
    "revision": "7e9d84e346ce158d1e50",
    "url": "./static/js/runtime-main.44d30fc2.js"
  },
  {
    "revision": "99c6de9522e46c9c69649216e988ae5e",
    "url": "./static/media/IBMPlexSans-Bold.99c6de95.ttf"
  },
  {
    "revision": "ee83103a4a777209b0f759a4ff598066",
    "url": "./static/media/IBMPlexSans-Medium.ee83103a.ttf"
  },
  {
    "revision": "c02b4dc6554c116e4c40f254889d5871",
    "url": "./static/media/IBMPlexSans-Regular.c02b4dc6.ttf"
  },
  {
    "revision": "1ca9107e7544d3424419585c7c84cb67",
    "url": "./static/media/IBMPlexSans-SemiBold.1ca9107e.ttf"
  },
  {
    "revision": "3ed9575dcc488c3e3a5bd66620bdf5a4",
    "url": "./static/media/OpenSans-Regular.3ed9575d.ttf"
  }
]);